==> ejb-container-3.1-b22-sources.jar: org/glassfish/ejb/startup/EjbContainerStarter.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2006-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.ejb.startup;

import com.sun.ejb.containers.EjbContainerUtil;
import org.glassfish.internal.api.ServerContext;
import org.glassfish.api.container.Container;
import org.jvnet.hk2.annotations.Inject;
import org.jvnet.hk2.annotations.Service;
import org.jvnet.hk2.component.PostConstruct;
import org.jvnet.hk2.component.PreDestroy;

import java.util.logging.Logger;

/**
 * Ejb container service
 *
 * @author Mahesh Kannan
 */
@Service(name="org.glassfish.ejb.startup.EjbContainerStarter")
public class EjbContainerStarter
    implements Container, PostConstruct, PreDestroy {

    //@Inject Domain domain;

    @Inject
    ServerContext _serverContext;

    @Inject
    EjbContainerUtil ejbContainerUtilImpl;

    @Inject
    Logger logger;

    private String instanceName;

    public void postConstruct() {
        instanceName = _serverContext.getInstanceName();
    }    
    
    public void preDestroy() {
        
    }

    public String getName() {
        return "EjbContainer";
    }

    public Class<? extends org.glassfish.api.deployment.Deployer> getDeployer() {
        return EjbDeployer.class;
    }
}

==> ejb-container-3.2-b03-sources.jar: org/glassfish/ejb/startup/EjbContainerStarter.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2006-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.ejb.startup;

import com.sun.ejb.containers.EjbContainerUtil;
import org.glassfish.api.container.Container;
import org.jvnet.hk2.annotations.Inject;
import org.jvnet.hk2.annotations.Service;
import org.jvnet.hk2.component.PostConstruct;
import org.jvnet.hk2.component.PreDestroy;


/**
 * Ejb container service
 *
 * @author Mahesh Kannan
 */
@Service(name="org.glassfish.ejb.startup.EjbContainerStarter")
public class EjbContainerStarter
    implements Container, PostConstruct, PreDestroy {

    /**
     * Initializes EjbContainerUtilImpl instance with this injection so that
     * its instance is available to subsequent request, e.g., with
     * EjbContainerUtilImpl.getInstance().
     */
    @Inject
    EjbContainerUtil ejbContainerUtilImpl;

    public void postConstruct() {
    }    
    
    public void preDestroy() {
    }

    public String getName() {
        return "EjbContainer";
    }

    public Class<? extends org.glassfish.api.deployment.Deployer> getDeployer() {
        return EjbDeployer.class;
    }
}
